@@ -18,10 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#ifndef _GNU_SOURCE
-# define _GNU_SOURCE
-#endif
-
 #define G_LOG_DOMAIN "sysprof-details-page"
 
 #include "config.h"
@@ -135,7 +131,7 @@ update_cpu_info_cb (GObject      *object,
     gtk_label_set_label (self->cpu_label, str);
 }
 
-static gboolean
+static bool
 cpu_info_cb (const SysprofCaptureFrame *frame,
              gpointer                   user_data)
 {
