@@ -143,7 +143,7 @@ sysprof_display_profiler_stopped_cb (SysprofDisplay  *self,
       g_autoptr(SysprofCaptureReader) reader = NULL;
       g_autoptr(GError) error = NULL;
 
-      if (!(reader = sysprof_capture_writer_create_reader (writer, &error)))
+      if (!(reader = sysprof_capture_writer_create_reader_with_error (writer, &error)))
         {
           g_warning ("Failed to create capture creader: %s\n", error->message);
           gtk_stack_set_visible_child (priv->stack, GTK_WIDGET (priv->failed_view));
@@ -1071,11 +1071,36 @@ sysprof_display_open (SysprofDisplay *self,
 
   g_set_object (&priv->file, file);
 
-  if (!(reader = sysprof_capture_reader_new (path, &error)))
-    g_warning ("Failed to open capture: %s", error->message);
-  else
-    sysprof_display_load_async (self, reader, NULL, NULL, NULL);
+  if (!(reader = sysprof_capture_reader_new_with_error (path, &error)))
+    {
+      GtkWidget *dialog;
+      GtkWidget *window;
 
+      g_warning ("Failed to open capture: %s", error->message);
+
+      window = gtk_widget_get_ancestor (GTK_WIDGET (self), GTK_TYPE_WINDOW);
+      dialog = gtk_message_dialog_new (NULL,
+                                       GTK_DIALOG_MODAL,
+                                       GTK_MESSAGE_WARNING,
+                                       GTK_BUTTONS_CLOSE,
+                                       "%s",
+                                       _("The recording could not be opened"));
+      gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                                "%s",
+                                                error->message);
+      g_signal_connect (dialog,
+                        "response",
+                        G_CALLBACK (gtk_widget_destroy),
+                        NULL);
+      gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+      gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
+      gtk_window_present (GTK_WINDOW (dialog));
+      gtk_widget_destroy (GTK_WIDGET (self));
+
+      return;
+    }
+
+  sysprof_display_load_async (self, reader, NULL, NULL, NULL);
   update_title_child_property (self);
 }
 
@@ -1204,7 +1229,7 @@ sysprof_display_save (SysprofDisplay *self)
           g_autofree gchar *path = g_file_get_path (file);
           g_autoptr(GError) error = NULL;
 
-          if (!sysprof_capture_reader_save_as (priv->reader, path, &error))
+          if (!sysprof_capture_reader_save_as_with_error (priv->reader, path, &error))
             {
               GtkWidget *msg;
 
@@ -1248,3 +1273,17 @@ _sysprof_display_reload_page (SysprofDisplay *self,
                            priv->filter,
                            NULL, NULL, NULL);
 }
+
+void
+sysprof_display_add_to_selection (SysprofDisplay *self,
+                                  gint64          begin_time,
+                                  gint64          end_time)
+{
+  SysprofDisplayPrivate *priv = sysprof_display_get_instance_private (self);
+  SysprofSelection *selection;
+
+  g_return_if_fail (SYSPROF_IS_DISPLAY (self));
+
+  selection = sysprof_visualizers_frame_get_selection (priv->visualizers);
+  sysprof_selection_select_range (selection, begin_time, end_time);
+}
